"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util = require("util");
class CloudFormationResourceCounterPlugin {
    constructor(serverless, options) {
        this.serverless = serverless;
        this.options = options;
        this.hooks = {
            'after:deploy:deploy': this.process.bind(this)
        };
    }
    get stackName() {
        return util.format('%s-%s', this.serverless.service.getServiceName(), this.serverless.getProvider('aws').getStage());
    }
    fetch() {
        return this.serverless.getProvider('aws').request('CloudFormation', 'listStackResources', { StackName: this.stackName }, this.serverless.getProvider('aws').getStage(), this.serverless.getProvider('aws').getRegion());
    }
    count(resources) {
        return resources.length;
    }
    process() {
        Promise.resolve()
            .then(() => this.fetch())
            .then((response) => {
            const message = util.format('CloudFormation resource count: %d', this.count(response.StackResourceSummaries));
            this.serverless.cli.log(message);
        })
            .catch((error) => this.serverless.cli.log(util.format('Cannot count: %s!', error.message)));
    }
}
exports.CloudFormationResourceCounterPlugin = CloudFormationResourceCounterPlugin;
//# sourceMappingURL=plugin.js.map